@@ -316,7 +316,7 @@ yaml_syck_parser_handler
 
                     if (lang == NULL || (strEQ(lang, "perl"))) {
                         /* !perl/ref on it's own causes no blessing */
-                        if ( !strEQ(type, "ref:") && (*type != '\0')) {
+                        if ( !strEQ(type, "ref") && (*type != '\0')) {
                             sv_bless(sv, gv_stashpv(type, TRUE));
                         }
                     } else {
@@ -581,7 +581,7 @@ yaml_syck_emitter_handler
                 break;
             }
             default: {
-                syck_emit_map(e, OBJOF("tag:!perl:ref:"), MAP_NONE);
+                syck_emit_map(e, OBJOF("tag:!perl:ref"), MAP_NONE);
                 *tag = '\0';
                 syck_emit_item( e, (st_data_t)newSVpvn_share(REF_LITERAL, REF_LITERAL_LENGTH, 0) );
                 syck_emit_item( e, (st_data_t)SvRV(sv) );
@@ -820,7 +820,10 @@ DumpYAML
         SV *bdeparse = GvSV(gv_fetchpv(form("%s::DeparseObject", PACKAGE_NAME), TRUE, SVt_PV));
 
         if (!SvTRUE(bdeparse)) {
-            call_pv(form("%s::_init_deparse", PACKAGE_NAME), G_DISCARD|G_NOARGS);
+            eval_pv(form(
+                "local $@; require B::Deparse; $%s::DeparseObject = B::Deparse->new",
+                PACKAGE_NAME
+            ), 1);
         }
     }
 #endif
